// $Id: ICMPPacket.java,v 1.11 2001/06/26 22:48:39 pcharles Exp $

/***************************************************************************
 * Copyright (C) 2001, Patrick Charles and Jonas Lehmann                   *
 * Distributed under the Mozilla Public License                            *
 *   http://www.mozilla.org/NPL/MPL-1.1.txt                                *
 ***************************************************************************/
package net.sourceforge.jpcap.net;

import net.sourceforge.jpcap.util.AnsiEscapeSequences;
import net.sourceforge.jpcap.util.ArrayHelper;


/**
 * An ICMP packet.
 * <p>
 * Extends an IP packet, adding an ICMP header and ICMP data payload.
 *
 * @author Patrick Charles and Jonas Lehmann
 * @version $Revision: 1.11 $
 * @lastModifiedBy $Author: pcharles $
 * @lastModifiedAt $Date: 2001/06/26 22:48:39 $
 */
public class ICMPPacket extends IPPacket implements ICMPFields
{
  public ICMPPacket(int lLen, byte [] bytes) {
    super(lLen, bytes);

    int offset = lLen + IPFields.IP_HEADER_LEN;
    this.header = PacketEncoding.extractHeader(offset, ICMP_HEADER_LEN, bytes);
    this.data = PacketEncoding.extractData(offset, ICMP_HEADER_LEN, bytes);
  }

  /**
   * Fetch the icmp header, excluding icmp data payload.
   */
  public byte [] getHeader() {
    return header;
  }

  /**
   * Fetch data portion of the icmp header.
   */
  public byte [] getData() {
    return data;
  }

  /**
   * Fetch the ICMP message type, including subcode. Return value can be 
   * used with ICMPMessage.getDescription().
   * @return a 2-byte value containing the message type in the high byte
   * and the message type subcode in the low byte.
   */
  public int getMessageCode() {
    return ArrayHelper.extractInteger(header, 
                                      ICMP_CODE_POS, ICMP_CODE_LEN * 2);
  }

  /**
   * Fetch the ICMP message type code. Formerly .getMessageType().
   */
  public int getMessageMajorCode() {
    return ArrayHelper.extractInteger(header, ICMP_CODE_POS, ICMP_CODE_LEN);
  }

  /**
   * For backward compatibility. @deprecated use getMessageMajorCode().
   */
  public int getMessageType() {
    return getMessageMajorCode();
  }

  /**
   * Fetch the ICMP message subcode.
   */
  public int getMessageMinorCode() {
    return ArrayHelper.extractInteger(header, ICMP_CODE_POS + 1, 
                                      ICMP_CODE_LEN);
  }

  /**
   * Fetch the ICMP header checksum.
   */
  public int getChecksum() {
    return ArrayHelper.extractInteger(header, ICMP_CSUM_POS + 1, 
                                      ICMP_CSUM_LEN);
  }


  /**
   * Convert this ICMP packet to a readable string.
   */
  public String toString() {
    StringBuffer buffer = new StringBuffer();
    buffer.append('[');
    buffer.append(AnsiEscapeSequences.LIGHT_BLUE);
    buffer.append("ICMPPacket");
    buffer.append(AnsiEscapeSequences.RESET);
    buffer.append(": ");
    buffer.append(ICMPMessage.getDescription(getMessageCode()));
    buffer.append(", ");
    buffer.append(getSourceAddress() + " -> " + 
                  getDestinationAddress());
    buffer.append(" l=" + header.length + "," + data.length);
    buffer.append(']');

    return buffer.toString();
  }


  /**
   * ICMP header.
   */
  byte [] header;

  /**
   * ICMP data.
   */
  byte [] data;

  private String _rcsid = 
    "$Id: ICMPPacket.java,v 1.11 2001/06/26 22:48:39 pcharles Exp $";
}
